<?php

// TODO: Cache thumbnails for icon previews

require_once 'vendor/autoload.php';

use Alfred\Workflows\ItemParam\Mod;
use Alfred\Workflows\Workflow;

$workflow = new Workflow();

$lastModified = filemtime($workflow->data()->path());
$now = time();
$diffInMinutes = ($now - $lastModified) / 60;

if (null === $workflow->data()->readJson() || $diffInMinutes > 120) {
    $workflow->logger()->info('Updating data');
    $client = new GuzzleHttp\Client();
    $res = $client->request('GET', 'https://www.bing.com/HPImageArchive.aspx?format=js&n=12&pid=hp&uhd=1&uhdwidth=3840&uhdheight=2160');

    $workflow->data()->writeJson(json_decode($res->getBody())->images);
}

$data = $workflow->data()->readJson();

foreach ($data as $image) {
    $date = DateTime::createFromFormat('Ymd', $image['startdate']);
    $descDate = $date->format('M d, Y');

    $title = (array_key_exists('title', $image)) ? $image['title'] : $descDate;
    $desc = (array_key_exists('desc', $image)) ? $image['desc'] : $image['copyright'];

    $workflow->item()
        ->title($title)
        ->subtitle($desc)
        ->quickLookUrl('https://bing.com'.$image['urlbase'].'_UHD.jpg&w=480&h=270')
        ->arg('https://bing.com'.$image['url'])
        ->largeType('https://bing.com'.$image['url'])
        ->copy('https://bing.com'.$image['url'])
        ->cmd(function (Mod $mod) use ($image) {
            $mod->subtitle('Open the wallpaper in your browser')
                ->arg('https://bing.com'.$image['url'])
            ;
        })
    ;
}

$workflow->output();
